@@ -17,8 +17,12 @@ EXIT_PYTHON_TOO_OLD = 4
 # ---------- current working directory ---------
 
 def assert_git_repo():
+	for arg in sys.argv[1:]:
+		if arg.startswith('--git-dir'):
+			return
+
 	r = Runner()
-	cmd = ["git", "rev-parse", "--is-inside-work-tree"]
+	cmd = ["git", "rev-parse", "--is-inside-git-dir"]
 	try:
 		out = r.run_and_get_output(cmd)
 	except CommandError as e:
@@ -28,7 +32,7 @@ def assert_git_repo():
 			error(EXIT_GIT_NOT_INSTALLED, _("git is not installed."))
 
 	out = out.rstrip()
-	if out != "true":
+	if out == "true":
 		path = os.getcwd().split(os.sep)
 		try:
 			i = path.index('.git')
